@@ -26,6 +26,9 @@ FAILEDOPERATION = 'FailedOperation'
 # 数据库连接失败，请检查参数是否填写正确。
 FAILEDOPERATION_DATASOURCECONNECTIONFAILED = 'FailedOperation.DataSourceConnectionFailed'
 
+# 不能删除wedata项目关联的空间
+FAILEDOPERATION_DELETEWEDATAITEMSPACE = 'FailedOperation.DeleteWedataItemspace'
+
 # 作业的草稿不允许删除。
 FAILEDOPERATION_DRAFTCONFIGCANNOTDELETE = 'FailedOperation.DraftConfigCanNotDelete'
 
@@ -191,6 +194,12 @@ INVALIDPARAMETERVALUE_RUNJOBDESCRIPTIONSCOUNT = 'InvalidParameterValue.RunJobDes
 # RunType错误。
 INVALIDPARAMETERVALUE_RUNTYPE = 'InvalidParameterValue.RunType'
 
+# 时间戳范围有误。
+INVALIDPARAMETERVALUE_TIMESTAMP = 'InvalidParameterValue.Timestamp'
+
+# 非法的类型字段。
+INVALIDPARAMETERVALUE_TYPE = 'InvalidParameterValue.Type'
+
 # 不支持的复合类型。
 INVALIDPARAMETERVALUE_UNSUPPORTEDCOMPOSITE = 'InvalidParameterValue.UnSupportedComposite'
 
@@ -254,6 +263,9 @@ RESOURCENOTFOUND_RESOURCECONFIG = 'ResourceNotFound.ResourceConfig'
 # 资源不存在。
 RESOURCENOTFOUND_RESOURCENOTEXIST = 'ResourceNotFound.ResourceNotExist'
 
+# 数据库或表不存在。
+RESOURCENOTFOUND_TABLENOTEXIST = 'ResourceNotFound.TableNotExist'
+
 # 资源不可用。
 RESOURCEUNAVAILABLE = 'ResourceUnavailable'
 
@@ -272,7 +284,7 @@ RESOURCEUNAVAILABLE_CLUSTERGROUPSTATUS = 'ResourceUnavailable.ClusterGroupStatus
 # 失败的目标资源。
 RESOURCEUNAVAILABLE_FAILEDTOBESCRIBERESOURCES = 'ResourceUnavailable.FailedToBescribeResources'
 
-# 获取发布的作业作业配置错误。
+# 获取发布的作业配置错误。
 RESOURCEUNAVAILABLE_GETJOBPUBLISHEDJOBCONFIG = 'ResourceUnavailable.GetJobPublishedJobConfig'
 
 # 作业资源配置未就绪。
